@@ -3,17 +3,16 @@
 .conflicts.OK <- TRUE
 
 
-.onAttach <- function(libname, pkgname) { 
+.onAttach <- function(libname, pkgname) {
   pkg <- Package(pkgname);
   assign(pkgname, pkg, pos=getPosition(pkg));
 
-  packageStartupMessage(getName(pkg), " v", getVersion(pkg), " (", 
-    getDate(pkg), ") successfully loaded. See ?", pkgname, " for help.");
+  startupMessage(pkg);
 }
 
 
 ############################################################################
-# HISTORY: 
+# HISTORY:
 # 2011-07-23
 # o Added a namespace to the package.
 ############################################################################
